import React from 'react';
import PropTypes from 'prop-types';
import Input, { InputLabel } from 'material-ui/Input';
import { FormControl, FormHelperText } from 'material-ui/Form';
import Select from 'material-ui/Select';

let lastId = 0;

function newId(prefix='element_') {
    lastId++;
    return `${prefix}${lastId}`;
}


let elementId = newId()

const SelectComponent = ({ items, value, handleChange, name, label, ...props }) => (
  <FormControl className={props.className}>
    <InputLabel htmlFor={elementId}>{label}</InputLabel>
    <Select
      native
      value={value}
      onChange={(event) => {handleChange(event.target.value)}}
      input={<Input id={elementId} />}
    >
      {items.map((child) => {return (
        <option value={child.key} key={child.key}>{child.title}</option>
      )})}
    </Select>
    {props.label ? <FormHelperText>{props.label}</FormHelperText> : ''}

  </FormControl>
)

SelectComponent.propTypes = {
  items: PropTypes.arrayOf(
    PropTypes.shape({
      key: PropTypes.node.isRequired,
      title: PropTypes.string.isRequired,
    }).isRequired
  ).isRequired,
  value: PropTypes.node,
  handleChange: PropTypes.func.isRequired
}

export default SelectComponent